pyLBM.elements.Triangle
=======================

.. currentmodule:: pyLBM.elements

.. autoclass:: Triangle

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Triangle.distance
         Triangle.get_bounds
         Triangle.point_inside
         Triangle.test_label



   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Triangle.number_of_bounds

